!function(t,e){"object"==typeof exports&&"object"==typeof module?module.exports=e():"function"==typeof define&&define.amd?define([],e):"object"==typeof exports?exports.ie=e():(t.Airflow=t.Airflow||{},t.Airflow.ie=e())}(window,(function(){return function(t){var e={};function r(n){if(e[n])return e[n].exports;var o=e[n]={i:n,l:!1,exports:{}};return t[n].call(o.exports,o,o.exports,r),o.l=!0,o.exports}return r.m=t,r.c=e,r.d=function(t,e,n){r.o(t,e)||Object.defineProperty(t,e,{enumerable:!0,get:n})},r.r=function(t){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})},r.t=function(t,e){if(1&e&&(t=r(t)),8&e)return t;if(4&e&&"object"==typeof t&&t&&t.__esModule)return t;var n=Object.create(null);if(r.r(n),Object.defineProperty(n,"default",{enumerable:!0,value:t}),2&e&&"string"!=typeof t)for(var o in t)r.d(n,o,function(e){return t[e]}.bind(null,o));return n},r.n=function(t){var e=t&&t.__esModule?function(){return t.default}:function(){return t};return r.d(e,"a",e),e},r.o=function(t,e){return Object.prototype.hasOwnProperty.call(t,e)},r.p="",r(r.s=4)}([,,,,function(t,e,r){"use strict";r.r(e);r(5)},function(t,e,r){(function(t){!function(t){"use strict";var e,r=function(){try{if(t.URLSearchParams&&"bar"===new t.URLSearchParams("foo=bar").get("foo"))return t.URLSearchParams}catch(t){}return null}(),n=r&&"a=1"===new r({a:1}).toString(),o=r&&"+"===new r("s=%2B").get("s"),i=!r||((e=new r).append("s"," &"),"s=+%26"===e.toString()),a=s.prototype,c=!(!t.Symbol||!t.Symbol.iterator);if(!(r&&n&&o&&i)){a.append=function(t,e){y(this.__URLSearchParams__,t,e)},a.delete=function(t){delete this.__URLSearchParams__[t]},a.get=function(t){var e=this.__URLSearchParams__;return this.has(t)?e[t][0]:null},a.getAll=function(t){var e=this.__URLSearchParams__;return this.has(t)?e[t].slice(0):[]},a.has=function(t){return v(this.__URLSearchParams__,t)},a.set=function(t,e){this.__URLSearchParams__[t]=[""+e]},a.toString=function(){var t,e,r,n,o=this.__URLSearchParams__,i=[];for(e in o)for(r=l(e),t=0,n=o[e];t<n.length;t++)i.push(r+"="+l(n[t]));return i.join("&")};var u=!!o&&r&&!n&&t.Proxy;Object.defineProperty(t,"URLSearchParams",{value:u?new Proxy(r,{construct:function(t,e){return new t(new s(e[0]).toString())}}):s});var f=t.URLSearchParams.prototype;f.polyfill=!0,f.forEach=f.forEach||function(t,e){var r=d(this.toString());Object.getOwnPropertyNames(r).forEach((function(n){r[n].forEach((function(r){t.call(e,r,n,this)}),this)}),this)},f.sort=f.sort||function(){var t,e,r,n=d(this.toString()),o=[];for(t in n)o.push(t);for(o.sort(),e=0;e<o.length;e++)this.delete(o[e]);for(e=0;e<o.length;e++){var i=o[e],a=n[i];for(r=0;r<a.length;r++)this.append(i,a[r])}},f.keys=f.keys||function(){var t=[];return this.forEach((function(e,r){t.push(r)})),p(t)},f.values=f.values||function(){var t=[];return this.forEach((function(e){t.push(e)})),p(t)},f.entries=f.entries||function(){var t=[];return this.forEach((function(e,r){t.push([r,e])})),p(t)},c&&(f[t.Symbol.iterator]=f[t.Symbol.iterator]||f.entries)}function s(t){((t=t||"")instanceof URLSearchParams||t instanceof s)&&(t=t.toString()),this.__URLSearchParams__=d(t)}function l(t){var e={"!":"%21","'":"%27","(":"%28",")":"%29","~":"%7E","%20":"+","%00":"\0"};return encodeURIComponent(t).replace(/[!'\(\)~]|%20|%00/g,(function(t){return e[t]}))}function h(t){return t.replace(/[ +]/g,"%20").replace(/(%[a-f0-9]{2})+/gi,(function(t){return decodeURIComponent(t)}))}function p(e){var r={next:function(){var t=e.shift();return{done:void 0===t,value:t}}};return c&&(r[t.Symbol.iterator]=function(){return r}),r}function d(t){var e={};if("object"==typeof t)if(_(t))for(var r=0;r<t.length;r++){var n=t[r];if(!_(n)||2!==n.length)throw new TypeError("Failed to construct 'URLSearchParams': Sequence initializer must only contain pair elements");y(e,n[0],n[1])}else for(var o in t)t.hasOwnProperty(o)&&y(e,o,t[o]);else{0===t.indexOf("?")&&(t=t.slice(1));for(var i=t.split("&"),a=0;a<i.length;a++){var c=i[a],u=c.indexOf("=");-1<u?y(e,h(c.slice(0,u)),h(c.slice(u+1))):c&&y(e,h(c),"")}}return e}function y(t,e,r){var n="string"==typeof r?r:null!=r&&"function"==typeof r.toString?r.toString():JSON.stringify(r);v(t,e)?t[e].push(n):t[e]=[n]}function _(t){return!!t&&"[object Array]"===Object.prototype.toString.call(t)}function v(t,e){return Object.prototype.hasOwnProperty.call(t,e)}}(void 0!==t?t:"undefined"!=typeof window?window:this)}).call(this,r(6))},function(t,e){var r;r=function(){return this}();try{r=r||new Function("return this")()}catch(t){"object"==typeof window&&(r=window)}t.exports=r}])}));