!function(e,t){"object"==typeof exports&&"object"==typeof module?module.exports=t():"function"==typeof define&&define.amd?define([],t):"object"==typeof exports?exports.connectionForm=t():(e.Airflow=e.Airflow||{},e.Airflow.connectionForm=t())}(window,(function(){return function(e){var t={};function n(o){if(t[o])return t[o].exports;var r=t[o]={i:o,l:!1,exports:{}};return e[o].call(r.exports,r,r.exports,n),r.l=!0,r.exports}return n.m=e,n.c=t,n.d=function(e,t,o){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:o})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var o=Object.create(null);if(n.r(o),Object.defineProperty(o,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var r in e)n.d(o,r,function(t){return e[t]}.bind(null,r));return o},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=3)}({3:function(e,t){$(document).ready((function(){var e={jdbc:{hidden_fields:["port","schema","extra"],relabeling:{host:"Connection URL"}},google_cloud_platform:{hidden_fields:["host","schema","login","password","port","extra"],relabeling:{}},cloudant:{hidden_fields:["port","extra"],relabeling:{host:"Account",login:"Username (or API Key)",schema:"Database"}},docker:{hidden_fields:["port","schema"],relabeling:{host:"Registry URL",login:"Username"}},qubole:{hidden_fields:["login","schema","port","extra"],relabeling:{host:"API Endpoint",password:"Auth Token"},placeholders:{host:"https://<env>.qubole.com/api"}},ssh:{hidden_fields:["schema"],relabeling:{login:"Username"}},spark:{hidden_fields:["schema","login","password"],relabeling:{}}};function t(t){$(".hide").removeClass("hide"),$.each($("[id^='extra__']"),(function(){$(this).parent().parent().addClass("hide")})),$.each($("[id^='extra__"+t+"']"),(function(){$(this).parent().parent().removeClass("hide")})),$("label[orig_text]").each((function(){$(this).text($(this).attr("orig_text"))})),$(".form-control").each((function(){$(this).attr("placeholder","")})),null!=e[t]&&($.each(e[t].hidden_fields,(function(e,t){$("#"+t).parent().parent().addClass("hide")})),$.each(e[t].relabeling,(function(e,t){lbl=$("label[for='"+e+"']"),lbl.attr("orig_text",lbl.text()),$("label[for='"+e+"']").text(t)})),$.each(e[t].placeholders,(function(e,t){$("#"+e).attr("placeholder",t)})))}var n=$("#conn_type").val();$("#conn_type").on("change",(function(e){t(n=$("#conn_type").val())})),t(n)}))}})}));